==> haskell-criterion-1.6.3.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion
version:              1.6.3.0
visibility:           public
id:                   criterion-1.6.3.0-6jiA0eLxzuhKLfuF96zXyU
key:                  criterion-1.6.3.0-6jiA0eLxzuhKLfuF96zXyU
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  9b1e2c2ff755529172f27b9c362c07f4
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.6.3.0-6jiA0eLxzuhKLfuF96zXyU
depends:
    Glob-0.10.2-M1TGhcFuRKLWsm8AwT12L
    aeson-2.1.2.1-HvDDR856aNq5cfhhuYXFVB base-4.17.2.1
    base-compat-batteries-0.13.1-5jZ8ebvZHdU9rLWWV2VhSV binary-0.8.9.1
    binary-orphans-1.0.5-IxngJrQ3jHi8jlFfHH25hV bytestring-0.11.5.3
    cassava-0.5.4.1-Am7I90DshtWFMbJHsNdSBr
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    criterion-measurement-0.2.3.0-1VYxAHfHCPfA9JOfMyMqYp
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 js-chart-2.9.4.1-IBsFHDloWlsCcv9nYHmzO5
    microstache-1.0.2.3-7mmeieLIxef5abHDJQHEYs mtl-2.2.2
    mwc-random-0.15.2.0-LkT98dFeVArHN9OM5l3cJK
    optparse-applicative-0.18.1.0-6vzfjdGcscpK23HoS6KcvN
    parsec-3.1.16.1 prettyprinter-1.7.1-7LCr279S4u97FneESew6z
    prettyprinter-ansi-terminal-1.1.3-9QGQBbp5h95K5T1zzYNOLO
    statistics-0.16.3.0-B0CF35zbToIF89oHfsyF2o text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    vector-0.13.2.0-4gUGda2ISIbCv9ACnxMPCL
    vector-algorithms-0.9.1.0-GRr0MFFjhy0G1ooAnxyoxp

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.6.3.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion
version:              1.6.3.0
visibility:           public
id:                   criterion-1.6.3.0-Fk2hvJ7mf4pFPLxDZK66fL
key:                  criterion-1.6.3.0-Fk2hvJ7mf4pFPLxDZK66fL
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  120c84a0a8deb5319ea8865293a88f83
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.6.3.0-Fk2hvJ7mf4pFPLxDZK66fL
depends:
    Glob-0.10.2-M1TGhcFuRKLWsm8AwT12L
    aeson-2.1.2.1-9cza8YJPY5Z8Ze3x8zf5ig base-4.17.2.1
    base-compat-batteries-0.13.1-5jZ8ebvZHdU9rLWWV2VhSV binary-0.8.9.1
    binary-orphans-1.0.5-IxngJrQ3jHi8jlFfHH25hV bytestring-0.11.5.3
    cassava-0.5.4.1-Am7I90DshtWFMbJHsNdSBr
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    criterion-measurement-0.2.3.0-K2bYAS8fjRoC5FlgoVe60K
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 js-chart-2.9.4.1-IBsFHDloWlsCcv9nYHmzO5
    microstache-1.0.2.3-63jjQ8xTgBlAP2jV7bCrhh mtl-2.2.2
    mwc-random-0.15.2.0-LkT98dFeVArHN9OM5l3cJK
    optparse-applicative-0.18.1.0-6vzfjdGcscpK23HoS6KcvN
    parsec-3.1.16.1 prettyprinter-1.7.1-7LCr279S4u97FneESew6z
    prettyprinter-ansi-terminal-1.1.3-9QGQBbp5h95K5T1zzYNOLO
    statistics-0.16.3.0-1tQAjHr5l7I2cnOwDCavgC text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    vector-0.13.2.0-4gUGda2ISIbCv9ACnxMPCL
    vector-algorithms-0.9.1.0-KqNhztVTy7ULmUUxsNXmDU

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
